#!/usr/bin/env python
# -*- coding: utf-8 -*-

# DONE:
# - better links and email handling
# - LaTeX Handler

# TODO :
# - escaping
# - footnotes
# - tables

# Core Imports
import re
import os
import string
import sys
import pprint
import codecs

try :
    import psyco
    psyco.full()
except:
    pass

# Internal Imports
from handler import HTMLHandler, LatexHandler

f = open('tex.tpl','r')
contents = f.read()
f.close()
ST_latex = string.Template(contents)

ST_html = string.Template("""<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
    <title>t2w | WikiDot Parser</title>
    <link rel="stylesheet" type="text/css" href="style.css" />
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    <meta http-equiv="Content-Language" content="en" />
    
    <script type="text/javascript"src="LaTeXMathML.js"></script>
</head>

<body>
<div id="wrap">
<div id="top">
    <h2><a href="/">WikiDot Parser</a></h2>
    <div id="menu">
        <ul>
            <li><a href="/" class="current">Home</a></li>
            <li><a href="download.html">Download</a></li>
            <li><a href="contact.html">Contact</a></li>
        </ul>
    </div>
</div>
<div id="content">
<div id="left">
$contents
</div>
</div>
</div>
</body>
</html>
""")

## =======================
## CLASSES
## =======================

class Parser(object):
    """
    The Parser class provides some genrators methods to divide
    the given text file to an organised something.
    
    To create a Parser one needs to provide
    
    @test : text to parse
    @table : a list of 2-tuples containing :
                - the name of the regexp
                - the regular expression
    @handler : a Handler instance (inline parsing against blocks)
    
    """
    
    
    """
    Pour échapper :
    Faut-il ajouter ceci par ex:
    (?<!@@)(toto)(?!@@)
    qui ne capturera toto que s'il n'est pas entouré par @@ et @@ ?
    """
    RULES =(
    ('esc', re.compile(r'@@(?P<contents>.+?)@@', re.MULTILINE| re.DOTALL) ),
    ('hrule', re.compile(r'(^-{4,})') ),
    ('bold', re.compile(r'\*(?P<bold>.+?)\*', re.MULTILINE| re.DOTALL) ),
    ('italic', re.compile(r'(?<!http:)//(?P<italics>.+?)//', re.MULTILINE| re.DOTALL) ),
    ('underline', re.compile(r'__(?P<underline>.+?)__', re.MULTILINE| re.DOTALL) ),
    ('stroked', re.compile(r'--(.+?)--', re.MULTILINE|re.DOTALL) ),
    ('exponant', re.compile(r'\^{2}(.+?)\^{2}'  , re.DOTALL) ),
    ('indice', re.compile(r'[.]{2}(.+?)[.]{2}', re.DOTALL) ),
    ('url', re.compile(r'\[(http://[\.a-zA-Z/0-9\:\#-?]+)(?: (?P<replacement>.+))?\]', re.MULTILINE|re.DOTALL) ),
    ('mail', re.compile(r'\[([\.a-zA-Z0-9]+@[\.a-zA-Z]+[a-zA-Z]+)(?: (?P<replacement>.+))?\]', re.MULTILINE|re.DOTALL) ),
    ('monospace', re.compile(r'[{]{2}(.+?)[}]{2}', re.MULTILINE|re.DOTALL) ),
    ('math', re.compile(r'\[\[math\]\](.+?)\[\[/math\]\]', re.MULTILINE|re.DOTALL) ),
    ('image', re.compile(r"\[\[image (?P<source>.+?)(?: (?P<align>.+))?(?: (?P<ref>.+))?\]\]", re.MULTILINE|re.DOTALL) ),
    )
    
    def __init__(self, text, table, handler = None):
        self.text = text
        self.table = [ (tag, re.compile(regex)) for tag, regex in table ]
        self.handler = handler
        self.handler.parent = self
        self.toc = []
        self.filters = []
        self.states = []
        self.sortie = []
        
        for n,p in self.RULES :
            self.addFilter(n,p)

    def addFilter(self, name, pattern):
        def filter(block, handler):
            return pattern.sub(self.handler.sub(name), block)
        self.filters.append(filter)

    def lines_generator(self):
        for i,l in enumerate(self.text.split("\n")):
            yield (i,l)
        
    def tokenize (self):
        """A generator yielding 'intelligent' blocks of text.
        
        """
        
        ret, code, lists = [], [], []
        incode = False
        lang = None
        
        # maybe I need this later on for line numbers matching
        # the_lines = self.text.split("\n") 
        the_lines = self.lines_generator()
        
        for linenum,line in the_lines:

            for (tag, regex) in self.table:
                
                mo = regex.match(line) # matched object

                # if we matched something in the table
                if mo :
                    
                    # it is start or end of Code
                    if tag in ("BEG_CODE","END_CODE") :
                        incode = not incode
                        self.states.append((linenum,tag))
                        if tag == "BEG_CODE" :
                            lang = mo.group("lang")
                        
                        if not incode:
                            yield ("CODE", ("\n".join(code), lang) )
                            code = []
                            
                    # we matched TEXT line
                    elif tag == "TEXT" :
                        if incode :
                            code.append((mo.groups()[0]).decode('utf-8'))
                        else:
                            self.states.append((linenum,tag))
                            ret.append((mo.groups()[0]).decode('utf-8'))

                    # we matched a BLANK line
                    elif tag == "BLANK" :
                        if incode :
                            code.append(u"".decode('utf-8'))
                            
                        else:
                            if ret :
                                yield('PARAGRAPH',("\n".join(ret),))
                                ret = []
                                
                    elif tag == "HEADER" :
                        self.toc.append((mo.group("title").decode('utf-8'), len(mo.groups()[0])))
                        yield('HEADER', (mo.group("title").decode('utf-8'), (mo.groups()[0]).decode('utf-8')))
                            
                    break # do not pass to another tag

## =======================
## MAIN APPLICATION
## =======================
def main():
    f = open('manual.txt','r')
    text = f.read()
    f.close()
    
    bloc_table = (
            ('HEADER',      r"^(?P<level>\++)\s*(?P<title>.+?)$"),
            ('BEG_CODE',    r'^(?P<beg_code>\[\[code(?: type="(?P<lang>.+?)")?\]\])$'),
            ('END_CODE',    r"^(?P<end_code>\[\[/code\]\])$"),
            ('BLANK',       r"^(?P<white>\s*)$"),
            ('TEXT',        r"^(?P<text>.+)$"),
            )

    h = HTMLHandler()
    t = LatexHandler()
    
    parseurHtml = Parser(text, bloc_table, h)
    parseurLatex = Parser(text, bloc_table, t)
    h.start()
    t.start()

    outputHtml = "\n".join(parseurHtml.sortie)
    out = ST_html.substitute(contents=outputHtml)
    f = open('manual.html','w')
    f.write(out)
    f.close()
    
    outputTex = "\n".join(parseurLatex.sortie)
    out = ST_latex.substitute(contents=outputTex)
    f = open('manual.tex','w')
    f.write(out)
    f.close()

if __name__ == "__main__":
    main()
