\documentclass[11pt]{book}

\usepackage{geometry}					% To define page size, margins, etc.
\usepackage[pdftex]{hyperref}			% For hyper-references in the generated PDF.
\usepackage[hyperref]{xcolor}			% To use colours in the document.
\usepackage[pdftex]{graphicx}			% To import graphics.
\usepackage{epstopdf}					% For on-the-fly conversion of eps to pdf.
\usepackage[francais]{babel}			% Pour la césure française.
\usepackage[utf8]{inputenc}				% For Latin1 (ISO-8859-1) input encoding.
\usepackage[T1]{fontenc}				% For T1 character encoding.
\usepackage{textcomp}					% For T1 character encoding.
\usepackage{ae}							% For T1 encoding using Type 1 fonts.
\usepackage{mathptmx}					% For Type 1 "Times Roman" serif text and math.
\usepackage[scaled=0.92]{helvet}		% For Type 1 "Helvetica" sans serif text.
\usepackage{courier}					% For Type 1 "Courier" monospaced text.
\usepackage{xspace}						% For automatic handling of spaces after macros.
\usepackage[titles]{tocloft}			% For Table of Contents customisation.
\usepackage{subfig}						% For subfigures.
\usepackage{fancyvrb}					% For fancy verbatim environments.
\usepackage[stable]{footmisc}			% For stable footnotes.
\usepackage{float}						% For extra control over floats.
\usepackage{titlesec}					% To configure sections headings.
\usepackage[nottoc]{tocbibind}			% To put the Bibliography in the TOC.
\usepackage{units}						% To typeset units.
\usepackage{xmpincl}					% To include Creative Commons metadata in XMP format.


%%Definition of the "subfloatenv" environment.


\makeatletter
\newsavebox{\sfe@box}
\newenvironment{subfloatenv}[1]{%
\def\sfe@caption{#1}%
\setbox\sfe@box\hbox\bgroup\color@setgroup}%
{\color@endgroup\egroup\subfloat[\sfe@caption]%
{\usebox{\sfe@box}}}
\makeatother

%%
%% Miscellaneous commands.
%%

\newcommand{\asyenv}{\texttt{asy}\xspace}
\newcommand{\asycom}{\texttt{asy}\xspace}
\newcommand{\asymptote}{\textsc{asymptote}\xspace}
\newcommand{\bibtex}{\textsc{bibtex}\xspace}
\newcommand{\latex}{\LaTeX\xspace}
\newcommand{\tex}{\TeX\xspace}
\newcommand{\postscript}{\textsc{postscript}\xspace}
\newcommand{\gnuplot}{\textsc{gnuplot}\xspace}
\newcommand{\xfig}{\textsc{xfig}\xspace}
\newcommand{\pstricks}{\textsc{PSTricks}\xspace}
\newcommand{\pdflatex}{\textsc{pdflatex}\xspace}
\newcommand{\pdftex}{\textsc{pdftex}\xspace}
\newcommand{\imagemagick}{\textsc{ImageMagick}\xspace}
\newcommand{\asyversion}{1.18\xspace}
\newcommand{\texcomm}[1]{$$\backslash$$\texttt{#1}\xspace}

%%
%% Definition of the colours used in the document.
%%

\definecolor{codefront}{rgb}{0,0,0}
\definecolor{codeback}{rgb}{1,1,0.8}
\definecolor{codeframe}{rgb}{0,0,0}
\definecolor{Brick}{HTML}{7B0C00}
\definecolor{RoyalBlue}{cmyk}{1,0.50,0,0}

%%
%% Code box configuration.
%%

\setlength{\fboxsep}{1em}
\setlength{\fboxrule}{1bp}
\newcommand{\displaycode}[1]{\fcolorbox{codeframe}{codeback}{\BUseVerbatim[formatcom=\color{codefront},fontsize=\small]{#1}}}

%%
%% TOC configuration.
%%

\setlength{\cftbeforesecskip}{0.1ex}
\setlength{\cftbeforesubsecskip}{0.1ex}
\renewcommand{\cftsecfont}{\normalfont}
\renewcommand{\cftsecpagefont}{\normalfont}
\renewcommand{\cftsecleader}{\cftdotfill{\cftdotsep}}

%%
%% Configure captions.
%%

\captionsetup{font=small,labelfont=bf,margin=2em}
\captionsetup[subfloat]{format=hang,font=small,labelfont=bf,margin=1em}

%%
%% Configure titles.
%%

\titleformat{name=\section}{\normalfont\rmfamily\Large\bfseries\color{Brick}}{\thesection.}{1em}{}
\titleformat{name=\section,numberless}{\normalfont\rmfamily\Large\bfseries\color{Brick}}{}{0em}{}
\titleformat{name=\subsection}{\normalfont\rmfamily\Large\bfseries\color{Brick}}{\thesubsection.}{1em}{}
\titleformat{name=\subsubsection}{\normalfont\rmfamily\large\bfseries\color{Brick}}{\thesubsubsection.}{1em}{}

%%
%% Configuration of paper geometry.
%%

\geometry{dvipdfm,a4paper,centering,tmargin=3.5cm,bmargin=3.5cm,lmargin=3.5cm,rmargin=3.5cm,nomarginpar}

%%
%% Hyperlink configuration.
%%

\hypersetup{%
	%pdftitle={\asymptote and \latex: An Integration Guide},
	%pdfauthor={Kib},
	%pdfsubject={asymptote},
	%pdfkeywords={typesetting, mathematical illustrations, asymptote, latex},
	plainpages=false,
	pdfpagelabels,
	hyperindex,
	colorlinks=true}

\hypersetup{linkcolor=RoyalBlue,urlcolor=RoyalBlue}

%-----------------------------------------------------------------------
%                       Listings simples
%-----------------------------------------------------------------------

\usepackage{listings} % a inclure pour la fonction listing
\usepackage{color} % on en a besoin pour utiliser les couleurs
\definecolor{grey}{rgb}{0.95,0.95,0.95} % on définit la couleur grise (c'est un gris très clair)

%-----------------------------------------------------------------------
%                       Pygments et listings simples
%-----------------------------------------------------------------------
\usepackage{fancyvrb}
%\newcommand\at{@}
\newcommand\lb{[}
\newcommand\rb{]}
\newcommand\Cba[1]{\textcolor[rgb]{0.00,0.00,0.50}{\textbf{#1}}}
\newcommand\Caz[1]{\textcolor[rgb]{0.00,0.63,0.00}{#1}}
\newcommand\Cay[1]{\textcolor[rgb]{0.00,0.50,0.00}{\textbf{#1}}}
\newcommand\Cax[1]{\textcolor[rgb]{0.60,0.60,0.60}{\textbf{#1}}}
\newcommand\Cbc[1]{\textcolor[rgb]{0.00,0.50,0.00}{\textbf{#1}}}
\newcommand\Cas[1]{\textcolor[rgb]{0.73,0.13,0.13}{\textit{#1}}}
\newcommand\Car[1]{\textcolor[rgb]{0.10,0.09,0.49}{#1}}
\newcommand\Caq[1]{\textcolor[rgb]{0.53,0.00,0.00}{#1}}
\newcommand\Cap[1]{\textcolor[rgb]{0.00,0.50,0.00}{#1}}
\newcommand\Caw[1]{\textcolor[rgb]{0.40,0.40,0.40}{#1}}
\newcommand\Cav[1]{\textcolor[rgb]{0.00,0.50,0.00}{\textbf{#1}}}
\newcommand\Cau[1]{\textcolor[rgb]{0.40,0.40,0.40}{#1}}
\newcommand\Cat[1]{\textcolor[rgb]{0.10,0.09,0.49}{#1}}
\newcommand\Cak[1]{\textcolor[rgb]{0.73,0.40,0.53}{#1}}
\newcommand\Caj[1]{\textcolor[rgb]{0.00,0.50,0.00}{#1}}
\newcommand\Cai[1]{\textcolor[rgb]{0.10,0.09,0.49}{#1}}
\newcommand\Cah[1]{\textcolor[rgb]{0.63,0.63,0.00}{#1}}
\newcommand\Cao[1]{\textcolor[rgb]{0.73,0.40,0.13}{\textbf{#1}}}
\newcommand\Can[1]{\textcolor[rgb]{0.67,0.13,1.00}{\textbf{#1}}}
\newcommand\Cam[1]{\textbf{#1}}
\newcommand\Cal[1]{\textcolor[rgb]{0.25,0.50,0.50}{\textit{#1}}}
\newcommand\Cac[1]{\textcolor[rgb]{0.73,0.13,0.13}{#1}}
\newcommand\Cab[1]{\textit{#1}}
\newcommand\Caa[1]{\textcolor[rgb]{0.50,0.50,0.50}{#1}}
\newcommand\Cag[1]{\textcolor[rgb]{0.40,0.40,0.40}{#1}}
\newcommand\Caf[1]{\textcolor[rgb]{0.25,0.50,0.50}{\textit{#1}}}
\newcommand\Cae[1]{\textcolor[rgb]{0.40,0.40,0.40}{#1}}
\newcommand\Cad[1]{\textcolor[rgb]{0.73,0.13,0.13}{#1}}
\newcommand\Cbb[1]{\textcolor[rgb]{0.40,0.40,0.40}{#1}}
\newcommand\CaZ[1]{\textcolor[rgb]{0.00,0.50,0.00}{\textbf{#1}}}
\newcommand\CaY[1]{\textcolor[rgb]{0.73,0.13,0.13}{#1}}
\newcommand\CaX[1]{\textcolor[rgb]{0.00,0.50,0.00}{#1}}
\newcommand\Cbf[1]{\textcolor[rgb]{0.73,0.40,0.53}{\textbf{#1}}}
\newcommand\Cbg[1]{\textcolor[rgb]{0.00,0.50,0.00}{\textbf{#1}}}
\newcommand\Cbd[1]{\textcolor[rgb]{0.73,0.13,0.13}{#1}}
\newcommand\Cbe[1]{\textcolor[rgb]{0.40,0.40,0.40}{#1}}
\newcommand\CaS[1]{\textcolor[rgb]{0.25,0.50,0.50}{\textit{#1}}}
\newcommand\CaR[1]{\textcolor[rgb]{0.10,0.09,0.49}{#1}}
\newcommand\CaQ[1]{\textcolor[rgb]{0.40,0.40,0.40}{#1}}
\newcommand\CaP[1]{\textcolor[rgb]{0.49,0.56,0.16}{#1}}
\newcommand\CaW[1]{\textcolor[rgb]{0.73,0.13,0.13}{#1}}
\newcommand\CaV[1]{\textcolor[rgb]{0.00,0.00,1.00}{\textbf{#1}}}
\newcommand\CaU[1]{\textcolor[rgb]{0.82,0.25,0.23}{\textbf{#1}}}
\newcommand\CaT[1]{\textcolor[rgb]{0.50,0.00,0.50}{\textbf{#1}}}
\newcommand\CaK[1]{\textcolor[rgb]{0.00,0.00,1.00}{#1}}
\newcommand\CaJ[1]{\textcolor[rgb]{0.73,0.13,0.13}{#1}}
\newcommand\CaI[1]{\textcolor[rgb]{0.69,0.00,0.25}{#1}}
\newcommand\CaH[1]{\fcolorbox[rgb]{1.00,0.00,0.00}{1,1,1}{#1}}
\newcommand\CaO[1]{\textcolor[rgb]{0.00,0.00,0.50}{\textbf{#1}}}
\newcommand\CaN[1]{\textcolor[rgb]{0.00,0.00,1.00}{\textbf{#1}}}
\newcommand\CaM[1]{\textcolor[rgb]{0.74,0.48,0.00}{#1}}
\newcommand\CaL[1]{\textcolor[rgb]{0.73,0.73,0.73}{#1}}
\newcommand\CaC[1]{\textcolor[rgb]{0.67,0.13,1.00}{#1}}
\newcommand\CaB[1]{\textcolor[rgb]{0.00,0.25,0.82}{#1}}
\newcommand\CaA[1]{\textcolor[rgb]{0.00,0.50,0.00}{#1}}
\newcommand\CaG[1]{\textcolor[rgb]{0.10,0.09,0.49}{#1}}
\newcommand\CaF[1]{\textcolor[rgb]{1.00,0.00,0.00}{#1}}
\newcommand\CaE[1]{\textcolor[rgb]{0.63,0.00,0.00}{#1}}
\newcommand\CaD[1]{\textcolor[rgb]{0.25,0.50,0.50}{\textit{#1}}}

%
% Pour le texte barré le package ulem
% Ensuite, \sout{mon texte}
%
\usepackage{ulem}

% Maths en mode plein
\everymath{\displaystyle}

%%
%% Main.
%%
%\DeclareUnicodeCharacter{005F}{i}
\begin{document}
\lstset{tabsize=2, frame=single, breaklines=true, basicstyle=\ttfamily,
   framexleftmargin=13mm, backgroundcolor=\color{grey}, xleftmargin=12mm}

$contents

\end{document}
